@@ -122,6 +122,18 @@ impl Default for Snapshot {
     }
 }
 
+impl Snapshot {
+    pub fn new_6128() -> Result<Self, String> {
+        let content = include_bytes!("cpc6128.sna").to_vec();
+        Self::from_buffer(content)
+    }
+
+    pub fn new_6128_v2() -> Result<Self, String> {
+        let content = include_bytes!("cpc6128_v2.sna").to_vec();
+        Self::from_buffer(content)
+    }
+}
+
 #[allow(missing_docs)]
 #[allow(unused)]
 impl Snapshot {
@@ -132,7 +144,6 @@ impl Snapshot {
     }
 
     pub fn load<P: AsRef<Path>>(filename: P) -> Result<Self, String> {
-        let mut sna = Self::default();
         let filename = filename.as_ref();
 
         // Read the full content of the file
@@ -143,6 +154,12 @@ impl Snapshot {
             content
         };
 
+        Self::from_buffer(file_content)
+    }
+
+    pub fn from_buffer(mut file_content: Vec<u8>) -> Result<Self, String> {
+        let mut sna = Self::default();
+
         // Copy the header
         sna.header
             .copy_from_slice(file_content.drain(0..0x100).as_slice());
@@ -180,6 +197,10 @@ impl Snapshot {
         self.header[0x10]
     }
 
+    pub fn version(&self) -> SnapshotVersion {
+        self.version_header().try_into().unwrap()
+    }
+
     /// Create a new snapshot that contains only information understandable
     /// by the required version
     /// TODO return an error in case of failure instead of panicing
@@ -195,9 +216,10 @@ impl Snapshot {
                 }
             }
             SnapshotVersion::V2 => {
-                for idx in 0x75..=0xFF {
-                    cloned.header[idx] = 0;
-                }
+                // for idx in 0x75..=0xFF {
+                //     cloned.header[idx] = 0;
+                // }
+                // unused but not set to 0
             }
             SnapshotVersion::V3 => {}
         };
@@ -241,7 +263,7 @@ impl Snapshot {
         cloned
     }
 
-    /// Save the snapshot V3 on disc
+    /// Save the snapshot V2 on disc
     #[deprecated]
     pub fn save_sna<P: AsRef<Path>>(&self, fname: P) -> Result<(), std::io::Error> {
         self.save(fname, SnapshotVersion::V2)
@@ -256,7 +278,11 @@ impl Snapshot {
         self.write(&mut buffer, version)
     }
 
-    pub fn write(&self, buffer: &mut File, version: SnapshotVersion) -> Result<(), std::io::Error> {
+    pub fn write<B: Write>(
+        &self,
+        buffer: &mut B,
+        version: SnapshotVersion
+    ) -> Result<(), std::io::Error> {
         // Convert the snapshot to ensure header is correct
         let sna = self.fix_version(version);
 
